@@ -460,8 +460,8 @@ impl<'a> Emitter<'a> {
             } else {
                 let mut s = num.value.to_string();
                 if self.cfg.minify {
-                    if !s.contains('.') && !s.contains('e') && s.ends_with("000") {
-                        let cnt = s.as_bytes().iter().rev().filter(|&&v| v == b'0').count();
+                    if !s.contains('.') && !s.contains('e') && s.ends_with("0000") {
+                        let cnt = s.as_bytes().iter().rev().filter(|&&v| v == b'0').count() - 1;
 
                         s.truncate(s.len() - cnt);
                         s.push('e');
